@@ -39,6 +39,10 @@ namespace mergerfs
       srcmountslock(),
       minfreespace(MINFREESPACE_DEFAULT),
       moveonenospc(false),
+      direct_io(false),
+      dropcacheonclose(false),
+      symlinkify(false),
+      symlinkify_timeout(3600),
       POLICYINIT(access),
       POLICYINIT(chmod),
       POLICYINIT(chown),
