@@ -14,6 +14,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __FALLOCATE_HPP__
+#define __FALLOCATE_HPP__
+
 namespace mergerfs
 {
   namespace fuse
@@ -26,3 +29,5 @@ namespace mergerfs
               fuse_file_info *fi);
   }
 }
+
+#endif
