@@ -16,9 +16,17 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include <errno.h>
+#ifndef __FS_BASE_FSYNC_HPP__
+#define __FS_BASE_FSYNC_HPP__
+
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+
 #include <unistd.h>
 
+#include "errno.hpp"
+
 namespace fs
 {
   static
@@ -41,3 +49,5 @@ namespace fs
 #endif
   }
 }
+
+#endif
