@@ -16,6 +16,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __FS_BASE_FTRUNCATE_HPP__
+#define __FS_BASE_FTRUNCATE_HPP__
+
 #include <sys/types.h>
 #include <unistd.h>
 
@@ -30,3 +33,5 @@ namespace fs
     return ::ftruncate(fd,size);
   }
 }
+
+#endif
