@@ -16,6 +16,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __FS_BASE_IOCTL_HPP__
+#define __FS_BASE_IOCTL_HPP__
+
 #include <sys/ioctl.h>
 
 namespace fs
@@ -23,10 +26,12 @@ namespace fs
   static
   inline
   int
-  ioctl(const int  fd,
-        const int  request,
-        void      *data)
+  ioctl(const int            fd,
+        const unsigned long  request,
+        void                *data)
   {
     return ::ioctl(fd,request,data);
   }
 }
+
+#endif
