@@ -16,6 +16,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __FS_BASE_LINK_HPP__
+#define __FS_BASE_LINK_HPP__
+
 #include <string>
 
 #include <unistd.h>
@@ -31,3 +34,5 @@ namespace fs
     return ::link(oldpath.c_str(),newpath.c_str());
   }
 }
+
+#endif
