@@ -16,6 +16,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __FS_BASE_OPENDIR_HPP__
+#define __FS_BASE_OPENDIR_HPP__
+
 #include <string>
 
 #include <dirent.h>
@@ -31,3 +34,5 @@ namespace fs
     return ::opendir(name.c_str());
   }
 }
+
+#endif
