@@ -16,6 +16,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __FS_BASE_READLINK_HPP__
+#define __FS_BASE_READLINK_HPP__
+
 #include <string>
 
 #include <unistd.h>
@@ -32,3 +35,5 @@ namespace fs
     return ::readlink(path.c_str(),buf,bufsiz);
   }
 }
+
+#endif
