@@ -16,6 +16,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __FS_BASE_WRITE_HPP__
+#define __FS_BASE_WRITE_HPP__
+
 #include <unistd.h>
 
 namespace fs
@@ -41,3 +44,5 @@ namespace fs
     return ::pwrite(fd,buf,count,offset);
   }
 }
+
+#endif
