@@ -14,6 +14,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __FS_CLONEFILE_HPP__
+#define __FS_CLONEFILE_HPP__
+
 #include <string>
 
 namespace fs
@@ -23,3 +26,5 @@ namespace fs
   int clonefile(const std::string &from,
                 const std::string &to);
 }
+
+#endif
