@@ -14,6 +14,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __FTRUNCATE_HPP__
+#define __FTRUNCATE_HPP__
+
 #include <fuse.h>
 
 #include <sys/types.h>
@@ -29,3 +32,5 @@ namespace mergerfs
               fuse_file_info *fi);
   }
 }
+
+#endif
