@@ -14,6 +14,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __GETATTR_HPP__
+#define __GETATTR_HPP__
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -27,3 +30,5 @@ namespace mergerfs
             struct stat *buf);
   }
 }
+
+#endif
