@@ -14,6 +14,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __GETXATTR_HPP__
+#define __GETXATTR_HPP__
+
 namespace mergerfs
 {
   namespace fuse
@@ -25,3 +28,5 @@ namespace mergerfs
              size_t      count);
   }
 }
+
+#endif
