@@ -14,6 +14,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __IOCTL_HPP__
+#define __IOCTL_HPP__
+
 namespace mergerfs
 {
   namespace fuse
@@ -27,3 +30,5 @@ namespace mergerfs
           void           *data);
   }
 }
+
+#endif
