@@ -20,12 +20,10 @@
 #include <cstdlib>
 #include <iostream>
 
+#include "fs_path.hpp"
 #include "mergerfs.hpp"
 #include "option_parser.hpp"
 #include "resources.hpp"
-#include "fs_path.hpp"
-
-#include "clone.hpp"
 
 #include "access.hpp"
 #include "chmod.hpp"
@@ -37,6 +35,7 @@
 #include "flock.hpp"
 #include "flush.hpp"
 #include "fsync.hpp"
+#include "fsyncdir.hpp"
 #include "ftruncate.hpp"
 #include "getattr.hpp"
 #include "getxattr.hpp"
@@ -68,22 +67,18 @@
 
 namespace local
 {
-  static
-  std::string
-  getappname(const int     argc,
-             char * const *argv)
-  {
-    return fs::path::basename(argv[0]);
-  }
-
   static
   void
-  get_fuse_operations(struct fuse_operations &ops)
+  get_fuse_operations(struct fuse_operations &ops,
+                      const bool              direct_io)
   {
+    ops.flag_nullpath_ok   = true;
 #if FLAG_NOPATH
-    ops.flag_nopath      = false;
+    ops.flag_nopath        = true;
+#endif
+#if FLAG_UTIME
+    ops.flag_utime_omit_ok = true;
 #endif
-    ops.flag_nullpath_ok = false;
 
     ops.access      = mergerfs::fuse::access;
     ops.bmap        = NULL;
@@ -100,7 +95,7 @@ namespace local
 #endif
     ops.flush       = mergerfs::fuse::flush;
     ops.fsync       = mergerfs::fuse::fsync;
-    ops.fsyncdir    = NULL;
+    ops.fsyncdir    = mergerfs::fuse::fsyncdir;
     ops.ftruncate   = mergerfs::fuse::ftruncate;
     ops.getattr     = mergerfs::fuse::getattr;
     ops.getdir      = NULL;       /* deprecated; use readdir */
@@ -115,7 +110,9 @@ namespace local
     ops.open        = mergerfs::fuse::open;
     ops.opendir     = mergerfs::fuse::opendir;
     ops.poll        = NULL;
-    ops.read        = mergerfs::fuse::read;
+    ops.read        = direct_io ?
+      mergerfs::fuse::read_direct_io :
+      mergerfs::fuse::read;
 #if READ_BUF
     ops.read_buf    = mergerfs::fuse::read_buf;
 #endif
@@ -133,7 +130,9 @@ namespace local
     ops.unlink      = mergerfs::fuse::unlink;
     ops.utime       = NULL;       /* deprecated; use utimens() */
     ops.utimens     = mergerfs::fuse::utimens;
-    ops.write       = mergerfs::fuse::write;
+    ops.write       = direct_io ?
+      mergerfs::fuse::write_direct_io :
+      mergerfs::fuse::write;
 #if WRITE_BUF
     ops.write_buf   = mergerfs::fuse::write_buf;
 #endif
@@ -172,7 +171,7 @@ namespace mergerfs
     mergerfs::options::parse(args,config);
 
     local::setup_resources();
-    local::get_fuse_operations(ops);
+    local::get_fuse_operations(ops,config.direct_io);
 
     return fuse_main(args.argc,
                      args.argv,
@@ -185,11 +184,5 @@ int
 main(int    argc,
      char **argv)
 {
-  std::string appname;
-
-  appname = local::getappname(argc,argv);
-  if(appname == "clone")
-    return clonetool::main(argc,argv);
-
   return mergerfs::main(argc,argv);
 }
