@@ -106,8 +106,8 @@ set_default_options(fuse_args &args)
 
 static
 int
-parse_and_process_minfreespace(const std::string &value,
-                               uint64_t          &minfreespace)
+parse_and_process(const std::string &value,
+                  uint64_t          &minfreespace)
 {
   int rv;
 
@@ -120,13 +120,27 @@ parse_and_process_minfreespace(const std::string &value,
 
 static
 int
-parse_and_process_moveonenospc(const std::string &value,
-                               bool              &moveonenospc)
+parse_and_process(const std::string &value,
+                  time_t            &time)
+{
+  int rv;
+
+  rv = num::to_time_t(value,time);
+  if(rv == -1)
+    return 1;
+
+  return 0;
+}
+
+static
+int
+parse_and_process(const std::string &value,
+                  bool              &boolean)
 {
   if(value == "false")
-    moveonenospc = false;
+    boolean = false;
   else if(value == "true")
-    moveonenospc = true;
+    boolean = true;
   else
     return 1;
 
@@ -140,10 +154,9 @@ parse_and_process_arg(Config            &config,
                       fuse_args         *outargs)
 {
   if(arg == "defaults")
-    {
-      set_default_options(*outargs);
-      return 0;
-    }
+    return (set_default_options(*outargs),0);
+  else if(arg == "direct_io")
+    return (config.direct_io=true,1);
 
   return 1;
 }
@@ -168,9 +181,15 @@ parse_and_process_kv_arg(Config            &config,
   else
     {
       if(key == "minfreespace")
-        rv = parse_and_process_minfreespace(value,config.minfreespace);
+        rv = parse_and_process(value,config.minfreespace);
       else if(key == "moveonenospc")
-        rv = parse_and_process_moveonenospc(value,config.moveonenospc);
+        rv = parse_and_process(value,config.moveonenospc);
+      else if(key == "dropcacheonclose")
+        rv = parse_and_process(value,config.dropcacheonclose);
+      else if(key == "symlinkify")
+        rv = parse_and_process(value,config.symlinkify);
+      else if(key == "symlinkify_timeout")
+        rv = parse_and_process(value,config.symlinkify_timeout);
     }
 
   if(rv == -1)
@@ -247,18 +266,31 @@ usage(void)
     "mergerfs options:\n"
     "    <srcpaths>             ':' delimited list of directories. Supports\n"
     "                           shell globbing (must be escaped in shell)\n"
-    "    -o defaults            default FUSE options which seem to provide the\n"
+    "    -o defaults            Default FUSE options which seem to provide the\n"
     "                           best performance: atomic_o_trunc, auto_cache,\n"
     "                           big_writes, default_permissions, splice_read,\n"
     "                           splice_write, splice_move\n"
-    "    -o direct_io           bypass additional caching, increases write\n"
-    "                           speeds at the cost of reads\n"
-    "    -o minfreespace=<int>  minimum free space needed for certain policies:\n"
-    "                           default 4G\n"
-    "    -o moveonenospc=<bool> try to move file to another drive when ENOSPC\n"
-    "                           on write: default false\n"
-    "    -o func.<f>=<p>        set function <f> to policy <p>\n"
-    "    -o category.<c>=<p>    set functions in category <c> to <p>\n"
+    "    -o func.<f>=<p>        Set function <f> to policy <p>\n"
+    "    -o category.<c>=<p>    Set functions in category <c> to <p>\n"
+    "    -o direct_io           Bypass additional caching, increases write\n"
+    "                           speeds at the cost of reads. Please read docs\n"
+    "                           for more details as there are tradeoffs.\n"
+    "    -o use_ino             Have mergerfs generate inode values rather than\n"
+    "                           autogenerated by libfuse. Suggested.\n"
+    "    -o minfreespace=<int>  minimum free space needed for certain policies.\n"
+    "                           default=4G\n"
+    "    -o moveonenospc=<bool> Try to move file to another drive when ENOSPC\n"
+    "                           on write. default=false\n"
+    "    -o dropcacheonclose=<bool>\n"
+    "                           When a file is closed suggest to OS it drop\n"
+    "                           the file's cache. This is useful when direct_io\n"
+    "                           is disabled. default=false\n"
+    "    -o symlinkify=<bool>   Read-only files, after a timeout, will be turned\n"
+    "                           into symlinks. Read docs for limitations and\n"
+    "                           possible issues. default=false\n"
+    "    -o symlinkify_timeout=<int>\n"
+    "                           timeout in seconds before will turn to symlinks.\n"
+    "                           default=3600\n"
             << std::endl;
 }
 
@@ -266,7 +298,8 @@ static
 void
 version(void)
 {
-  std::cout << "mergerfs version: " << MERGERFS_VERSION
+  std::cout << "mergerfs version: "
+            << MERGERFS_VERSION
             << std::endl;
 }
 
