@@ -14,6 +14,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __RWLOCK_HPP__
+#define __RWLOCK_HPP__
+
 #include <pthread.h>
 
 namespace mergerfs
@@ -63,3 +66,5 @@ namespace mergerfs
     };
   }
 }
+
+#endif
