@@ -14,6 +14,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __SETXATTR_HPP__
+#define __SETXATTR_HPP__
+
 namespace mergerfs
 {
   namespace fuse
@@ -26,3 +29,5 @@ namespace mergerfs
              int         flags);
   }
 }
+
+#endif
