@@ -14,6 +14,9 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#ifndef __WRITE_HPP__
+#define __WRITE_HPP__
+
 namespace mergerfs
 {
   namespace fuse
@@ -24,5 +27,14 @@ namespace mergerfs
           size_t          count,
           off_t           offset,
           fuse_file_info *fi);
+
+    int
+    write_direct_io(const char     *fusepath,
+                    const char     *buf,
+                    size_t          count,
+                    off_t           offset,
+                    fuse_file_info *fi);
   }
 }
+
+#endif
